@@ -171,7 +171,7 @@ class VariantBlock:
         if len(self.bitarrays) == 0:
             return 0
         else:
-            return self.bitarrays[0].length()
+            return len(self.bitarrays[0])
 
     def number_of_variants(self):
         return len(self.bitarrays)
@@ -250,7 +250,7 @@ def var_patterns_from_block_slices(block_files, wanted_variants, seq_id, start,
         if len(block) == 0:
             continue
         sorted_vars = sorted(list(block.keys()))
-        samples = block[sorted_vars[0]].length()
+        samples = len(block[sorted_vars[0]])
 
         for i in range(samples):
             var_pattern = tuple(sorted([v for v in sorted_vars if block[v][i]]))
@@ -316,6 +316,12 @@ class VariantTracker:
     def load_ref_seq_data(cls, fasta_file):
         seqs = {}
         pyfastaq.tasks.file_to_dict(fasta_file, seqs)
+        # Convert all nucleotides to uppercase, and only keep everything before
+        # first whitespace in sequence names
+        seqs = {k.split()[0]: v for k, v in seqs.items()}
+        for seq in seqs.values():
+            seq.id = seq.id.split()[0]
+            seq.seq = seq.seq.upper()
         ref_seq_names = sorted(seqs.keys())
         ref_seq_to_id = {x: i for i, x in enumerate(ref_seq_names)}
         return seqs, ref_seq_names, ref_seq_to_id
